@@ -1,5 +1,5 @@
 <?php
-// $Id: calendar_test.php 2 2007-11-03 04:59:01Z fishbone $
+// $Id: calendar_test.php 4940 2012-06-06 02:20:28Z fishbone $
 
 require_once('simple_include.php');
 require_once('calendar_include.php');
@@ -111,5 +111,14 @@ class TestOfCalendar extends UnitTestCase {
         $stamp = mktime(13,32,43,10,25,2003);
         $this->assertEqual($stamp,$this->cal->getTimeStamp());
     }
+    function testIsToday() {
+        $stamp = mktime();
+        $this->cal->setTimestamp($stamp);
+        $this->assertTrue($this->cal->isToday());
+
+        $stamp += 1000000000;
+        $this->cal->setTimestamp($stamp);
+        $this->assertFalse($this->cal->isToday());
+    }
 }
 ?>
\ No newline at end of file
