@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2011 Magic3 Project.
+ * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: analyzeManager.php 4909 2012-05-17 12:44:50Z fishbone $
+ * @version    SVN: $Id: analyzeManager.php 5045 2012-07-20 03:13:33Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/core.php');
@@ -117,8 +117,8 @@ class AnalyzeManager extends Core
 	function logContentDownload($contentType, $contentId)
 	{
 		// ダウンロードログ書き込み
-		$this->db->writeDownloadLog($contentType, $contentId);
-		return true;
+		$ret = $this->db->writeDownloadLog($contentType, $contentId);
+		return $ret;
 	}
 	/**
 	 * ブラウザのタイプを取得
