@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2014 Magic3 Project.
+ * @copyright  Copyright 2006-2015 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -132,10 +132,11 @@ class RequestManager extends Core
 	 * デフォルトでHTMLタグを取り除く
 	 *
 	 * @param string $name		キー値
-	 * @param string $default  	値が存在しないときのデフォルト値
+	 * @param string $default  	値が存在しないとき、値が空文字列のときのデフォルト値
 	 * @return string			取得値
 	 */
-	public function trimIntValueOf($name, $default = '')
+	//public function trimIntValueOf($name, $default = '')
+	public function trimIntValueOf($name, $default)			// デフォルト値必須(2015/2/13)
 	{
 		$srcValue = isset($_POST[$name]) ? $_POST[$name] : (isset($_GET[$name]) ? $_GET[$name] : $default);
 		return $this->_trimValueOf($name, $srcValue, $default, 1/* int型チェック */);
@@ -159,7 +160,7 @@ class RequestManager extends Core
 	/**
 	 * トリミング(前後の空白削除)処理
 	 *
-	 * デフォルトでHTMLタグを取り除く
+	 * デフォルトで不正な文字(HTMLタグ等)を取り除く
 	 *
 	 * @param string $name		キー値
 	 * @param string $value  	値
@@ -185,7 +186,9 @@ class RequestManager extends Core
 				$isValid = false;
 				if (strlen($stripValue) == strlen($trimValue[$key])){		// 文字列長が同じとき
 					if ($ckeckType == 1){		// int型チェック
-						if (is_numeric($stripValue) && !strstr($stripValue, '.')){
+						if ($stripValue == ''){				// 空文字列の場合はエラーと見なさない(2015/2/19 追加)
+							$isValid = true;
+						} else if (is_numeric($stripValue) && !strstr($stripValue, '.')){
 							$isValid = true;
 						} else {	// エラーの場合は値を修正
 							$stripValue = '';
@@ -220,11 +223,13 @@ class RequestManager extends Core
 			$saveValue = $destValue;
 			$destValue = $this->_convSafeText($destValue);
 			if ($destValue != $saveValue) $destValue = '';
-			
+
 			$isValid = false;
 			if (strlen($destValue) == strlen($trimValue)){		// 文字列長が同じとき
 				if ($ckeckType == 1){		// int型チェック
-					if (is_numeric($destValue) && !strstr($destValue, '.')){
+					if ($destValue == ''){				// 空文字列の場合はエラーと見なさない(2015/2/19 追加)
+						$isValid = true;
+					} else if (is_numeric($destValue) && !strstr($destValue, '.')){
 						$isValid = true;
 					} else {	// エラーの場合は値を修正
 						$destValue = '';
