@@ -31,6 +31,10 @@ DELETE FROM _widgets WHERE wd_id = 'test_ckeditor';
 INSERT INTO _widgets
 (wd_id,           wd_name,            wd_version, wd_author,      wd_copyright, wd_license, wd_official_level, wd_description, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_initialized, wd_install_dt, wd_create_dt) VALUES
 ('test_ckeditor', 'CKEditorテスト用', '1.0.0',    'Naoki Hirata', 'Magic3.org', 'GPL',      10, 'CKEditorテスト用のプログラム',  true,         true,        true,        false,               false,true,           now(), now());
+DELETE FROM _widgets WHERE wd_id = 'test_message';
+INSERT INTO _widgets
+(wd_id,           wd_name,            wd_version, wd_author,      wd_copyright, wd_license, wd_official_level, wd_description, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_initialized, wd_install_dt, wd_create_dt) VALUES
+('test_message', 'メッセージテスト用', '1.0.0',    'Naoki Hirata', 'Magic3.org', 'GPL',      10, 'メッセージ出力テスト用のプログラム',  true,         true,        true,        false,               false,true,           now(), now());
 
 -- ウィジェット情報(携帯用)
 DELETE FROM _widgets WHERE wd_id = 'm/sample';
