@@ -9,7 +9,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2014 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id$
+ * @version    1.2
  * @link       http://www.magic3.org
  */
 
@@ -28,14 +28,16 @@
 		var fakeImage;
 		var infoWindow;
 		var polyline;
+//		var inLoading;
 		
 		// スクリプト読み込み
-//		var path = CKEDITOR.plugins.getPath('googlemaps');
-//		CKEDITOR.scriptLoader.load(CKEDITOR.getUrl(path) + 'dialogs/polyline.js');
 		var pluginUrl = CKEDITOR.getUrl(CKEDITOR.plugins.getPath( 'googlemaps' ));
 			
 		var loadSelectionData = function()
 		{
+//			inLoading = true;		// データロード中
+			mapObj = null;			// オブジェクト一旦削除
+			
 			if (fakeImage){		// マップ選択からの起動の場合
 				var className = fakeImage.$.className;
 				var mapNumber;
@@ -46,19 +48,39 @@
 			} else {		// マップが選択されていない場合は新規作成
 				mapInfo = GoogleMapsHandler.createNew();
 			}
-			
+
 			// 入力値初期化
 			dialog.setValueOf('tab_map', 'txtWidth', mapInfo.width);
 			dialog.setValueOf('tab_map', 'txtHeight', mapInfo.height);
+			dialog.setValueOf('tab_map', 'cmbWidthType', mapInfo.widthType);
+			dialog.setValueOf('tab_map', 'cmbHeightType', mapInfo.heightType);
+			dialog.setValueOf('tab_map', 'chkAlignCenter', mapInfo.alignCenter);
 			dialog.setValueOf('tab_map', 'cmbZoom', mapInfo.zoom);
 			dialog.setValueOf('tab_map', 'txtCenterLat', mapInfo.centerLat);
 			dialog.setValueOf('tab_map', 'txtCenterLon', mapInfo.centerLon);
+			dialog.setValueOf('tab_option', 'chkZoomControl', mapInfo.zoomControl);
+			dialog.setValueOf('tab_option', 'chkPanControl', mapInfo.panControl);
+			dialog.setValueOf('tab_option', 'chkScaleControl', mapInfo.scaleControl);
+			dialog.setValueOf('tab_option', 'chkMapTypeControl', mapInfo.mapTypeControl);
+			dialog.setValueOf('tab_option', 'chkStreetViewControl', mapInfo.streetViewControl);
+			dialog.setValueOf('tab_option', 'chkRotateControl', mapInfo.rotateControl);
+			dialog.setValueOf('tab_option', 'chkOverviewMapControl', mapInfo.overviewMapControl);
+			dialog.setValueOf('tab_option', 'chkRoadmapMapType', mapInfo.roadmapMapType);
+			dialog.setValueOf('tab_option', 'chkSatelliteMapType', mapInfo.satelliteMapType);
+			dialog.setValueOf('tab_option', 'chkHybridMapType', mapInfo.hybridMapType);
+			dialog.setValueOf('tab_option', 'chkTerrainMapType', mapInfo.terrainMapType);
+			dialog.setValueOf('tab_style', 'txtStyle', mapInfo.style);
 //			dialog.setValueOf('tab_line', 'txtEncodedPolyline', mapInfo.linePoints);
 //			dialog.setValueOf('tab_line', 'txtEncodedLevels', mapInfo.lineLevels);
 			
-			// マップ作成
-			setPreviewElement(mapInfo.mapType);
+//			inLoading = false;		// データロード終了
 			
+			// プレビューマップ作成
+			createMap(mapInfo.mapType);
+			
+			// コントローラ設定
+			changeMap();
+				
 			// マーカー設定
 			var markerPoints = mapInfo.markerPoints;
 			for (var i = 0; i < markerPoints.length; i++)
@@ -71,20 +93,31 @@
 			polyline.setMap(mapObj);
 			polyline.decodePolyline(mapInfo.linePoints);
 		};
-		var setPreviewElement = function(mapType)
+		var createMap = function(mapType)
 		{
 			mapDiv = document.getElementById("gmapPreview" + editor.id);
 			resizeMap();
 	
-			var allMapTypes = [	google.maps.MapTypeId.ROADMAP,
+			// マップタイプ
+			var allMapTypes = [];
+			var val;
+			val = dialog.getValueOf('tab_option', 'chkRoadmapMapType');
+			if (val) allMapTypes.push(google.maps.MapTypeId.ROADMAP);
+			val = dialog.getValueOf('tab_option', 'chkSatelliteMapType');
+			if (val) allMapTypes.push(google.maps.MapTypeId.SATELLITE);
+			val = dialog.getValueOf('tab_option', 'chkHybridMapType');
+			if (val) allMapTypes.push(google.maps.MapTypeId.HYBRID);
+			val = dialog.getValueOf('tab_option', 'chkTerrainMapType');
+			if (val) allMapTypes.push(google.maps.MapTypeId.TERRAIN);
+/*			var allMapTypes = [	google.maps.MapTypeId.ROADMAP,
 							google.maps.MapTypeId.SATELLITE,
 							google.maps.MapTypeId.HYBRID,
-							google.maps.MapTypeId.TERRAIN	];
+							google.maps.MapTypeId.TERRAIN	];*/
 			var opts = { 	mapTypeId:allMapTypes[mapType],
 							mapTypeControlOptions:{	mapTypeIds:allMapTypes } };
 			mapObj = new google.maps.Map(mapDiv, opts);
 
-			updatePreview();
+			updateMap();
 			
 			// イベント設定
 			google.maps.event.addListener(mapObj, 'zoom_changed', function(){
@@ -100,6 +133,7 @@
 				var selectedTab = CKEDITOR.dialog.getCurrent().definition.dialog._.currentTabId;		// 選択中のタブIDを取得
 				switch (selectedTab){
 					case 'tab_map':
+					case 'tab_option':
 					case 'tab_search':
 						break;
 					case 'tab_marker':
@@ -120,6 +154,7 @@
 				if (iCode == 46){
 					switch(selectedTab){
 						case 'tab_map':
+						case 'tab_option':
 						case 'tab_search':
 						case 'tab_marker':
 							break;
@@ -130,16 +165,74 @@
 				}
 			});
 		};
+		var selectMap = function()
+		{
+			if (!mapObj) return;
+			
+			// マップタイプ
+			var allMapTypes = [];
+			var val;
+			val = dialog.getValueOf('tab_option', 'chkRoadmapMapType');
+			if (val) allMapTypes.push(google.maps.MapTypeId.ROADMAP);
+			val = dialog.getValueOf('tab_option', 'chkSatelliteMapType');
+			if (val) allMapTypes.push(google.maps.MapTypeId.SATELLITE);
+			val = dialog.getValueOf('tab_option', 'chkHybridMapType');
+			if (val) allMapTypes.push(google.maps.MapTypeId.HYBRID);
+			val = dialog.getValueOf('tab_option', 'chkTerrainMapType');
+			if (val) allMapTypes.push(google.maps.MapTypeId.TERRAIN);
+			
+			var opts = { 	mapTypeId: allMapTypes[0],
+							mapTypeControlOptions: {	mapTypeIds:allMapTypes } };
+			mapObj.setOptions(opts);
+		};
+		var changeMap = function(id)
+		{
+			// ダイアログ用のデータ読み込み中のときは終了
+//			if (inLoading) return;
+			if (!mapObj) return;
+			
+			var val;
+			if (!id || id == 'chkZoomControl'){
+				val = dialog.getValueOf('tab_option', 'chkZoomControl');
+				mapObj.setOptions({ zoomControl: val });
+			}
+			if (!id || id == 'chkPanControl'){
+				val = dialog.getValueOf('tab_option', 'chkPanControl');
+				mapObj.setOptions({ panControl: val });
+			}
+			if (!id || id == 'chkScaleControl'){
+				val = dialog.getValueOf('tab_option', 'chkScaleControl');
+				mapObj.setOptions({ scaleControl: val });
+			}
+			if (!id || id == 'chkMapTypeControl'){
+				val = dialog.getValueOf('tab_option', 'chkMapTypeControl');
+				mapObj.setOptions({ mapTypeControl: val });
+			}
+			if (!id || id == 'chkStreetViewControl'){
+				val = dialog.getValueOf('tab_option', 'chkStreetViewControl');
+				mapObj.setOptions({ streetViewControl: val });
+			}
+			if (!id || id == 'chkRotateControl'){
+				val = dialog.getValueOf('tab_option', 'chkRotateControl');
+				mapObj.setOptions({ rotateControl: val });
+			}
+			if (!id || id == 'chkOverviewMapControl'){
+				val = dialog.getValueOf('tab_option', 'chkOverviewMapControl');
+				mapObj.setOptions({ overviewMapControl: val, overviewMapControlOptions: { opened: true } });
+			}
+		};
 		var resizeMap = function()
 		{
 			if (!mapDiv) return;
 			
-			mapDiv.style.width = dialog.getValueOf('tab_map', 'txtWidth') + 'px';
-			mapDiv.style.height = dialog.getValueOf('tab_map', 'txtHeight') + 'px';
-
+//			mapDiv.style.width = dialog.getValueOf('tab_map', 'txtWidth') + 'px';
+//			mapDiv.style.height = dialog.getValueOf('tab_map', 'txtHeight') + 'px';
+			mapDiv.style.width = dialog.getValueOf('tab_map', 'txtWidth') + dialog.getValueOf('tab_map', 'cmbWidthType');
+			mapDiv.style.height = dialog.getValueOf('tab_map', 'txtHeight') + dialog.getValueOf('tab_map', 'cmbHeightType');
+			
 			//ResizeParent();
 		};
-		var updatePreview = function()
+		var updateMap = function()
 		{
 			if (!mapObj) return;
 
@@ -160,7 +253,7 @@
 					// 検索位置にマーカーを設定
 					addMarkerAtPoint(point, address);
 
-					updatePreview();
+					updateMap();
 				} else {
 					alert(editor.lang.googlemaps.msgNotFound.replace("%s", address));
 				}
@@ -276,6 +369,14 @@
 			if ( !data.info ) data.info = {};
 			data.info[id] = this.getValue();
 		};
+		var isJson = function(str){
+			try {
+				JSON.parse(str);
+			} catch (e) {
+				return false;
+			}
+			return true;
+		};
 		return {
 			title: editor.lang.googlemaps.title,
 			minWidth: 420,
@@ -289,18 +390,15 @@
 //				var height = dialog.getSize().height;
 //				dialog.resize(width, height);
 				
-				// マップの位置を修正
-/*				var off = $('#placeholder_map').position();
-				$('#placeholder_search').css({position:'absolute', top:off.top + 'px',left:off.left + 'px'});
-				$('#placeholder_marker').css({position:'absolute', top:off.top + 'px',left:off.left + 'px'});
-				$('#placeholder_line').css({position:'absolute', top:off.top + 'px',left:off.left + 'px'});
-				*/
 				// タブが変更された場合はマップを移動
 				dialog.on('selectPage', function(e){
 					switch (e.data.page){
 					case 'tab_map':
 						$('#gmapPreview' + editor.id).appendTo('#placeholder_map' + editor.id);
 						break;
+					case 'tab_option':
+						$('#gmapPreview' + editor.id).appendTo('#placeholder_option' + editor.id);
+						break;
 					case 'tab_search':
 						$('#gmapPreview' + editor.id).appendTo('#placeholder_search' + editor.id);
 						break;
@@ -325,9 +423,9 @@
 					addMarker();
 				}).attr({ title:editor.lang.googlemaps.addMarker, alt:editor.lang.googlemaps.addMarker });
 			},
-	/*		onFocus: function() {
+			onFocus: function() {		// 特定フィールドからフォーカスをはずす
 				mapDiv.focus();
-			},*/
+			},
 			onShow: function(){
 				// マップ初期化
 				markers = [];
@@ -341,6 +439,8 @@
 				} else {
 					fakeImage = null;
 				}
+				
+				// データロード
 				loadSelectionData();
 			},
 			onOk: function(){
@@ -353,9 +453,24 @@
 				// マップ情報更新
 				mapInfo.width = data.info['txtWidth'];
 				mapInfo.height = data.info['txtHeight'];
+				mapInfo.widthType = data.info['cmbWidthType'];
+				mapInfo.heightType = data.info['cmbHeightType'];
+				mapInfo.alignCenter = data.info['chkAlignCenter'];
 				mapInfo.zoom = data.info['cmbZoom'];
 				mapInfo.centerLat = data.info['txtCenterLat'];
 				mapInfo.centerLon = data.info['txtCenterLon'];
+				mapInfo.zoomControl = data.info['chkZoomControl'];
+				mapInfo.panControl = data.info['chkPanControl'];
+				mapInfo.scaleControl = data.info['chkScaleControl'];
+				mapInfo.mapTypeControl = data.info['chkMapTypeControl'];
+				mapInfo.streetViewControl = data.info['chkStreetViewControl'];
+				mapInfo.rotateControl = data.info['chkRotateControl'];
+				mapInfo.overviewMapControl = data.info['chkOverviewMapControl'];
+				mapInfo.roadmapMapType = data.info['chkRoadmapMapType'];
+				mapInfo.satelliteMapType = data.info['chkSatelliteMapType'];
+				mapInfo.hybridMapType = data.info['chkHybridMapType'];
+				mapInfo.terrainMapType = data.info['chkTerrainMapType'];
+				mapInfo.style = data.info['txtStyle'];
 				var markerPoints = [];
 				for (var i=0; i < markers.length; i++){
 					var point = markers[i].getPosition();
@@ -367,15 +482,14 @@
 				mapInfo.linePoints = polyline.encodedPolyline;
 				mapInfo.lineLevels = polyline.encodedLevels;
 				var script = mapInfo.buildScript();
-//				var scriptElement = CKEDITOR.dom.element.createFromHtml(script, editor.document);
-//				var newMapElement = CKEDITOR.dom.element.createFromHtml('<div></div>', editor.document);
-//				newMapElement.append(scriptElement);
 				var newMapElement = CKEDITOR.dom.element.createFromHtml('<div>' + script + '</div>', editor.document);		// IE8 not work.
-				var style = 'width:' + mapInfo.width + 'px;height:' + mapInfo.height + 'px;display:none;';
+				var style = 'width:' + mapInfo.width + mapInfo.widthType + ';height:' + mapInfo.height + mapInfo.heightType + ';display:none;';
+	//			var style = 'width:' + mapInfo.width + mapInfo.widthType + ';height:' + mapInfo.height + mapInfo.heightType + ';';
+				if (mapInfo.alignCenter) style += 'margin:0 auto;';
 				newMapElement.setAttributes({
 					'id': 'gmap' + mapInfo.number,
 					'style': style,
-					'class': 'm3googlemaps'
+					'class': 'googlemaps'
 				});
 
 				// ビュー更新前、画像のみ変更
@@ -383,8 +497,8 @@
 							'background-position': 'center center',
 							'background-repeat': 'no-repeat',
 							'border': '0px',
-							'width': mapInfo.width + 'px',
-							'height': mapInfo.height + 'px'
+							'width': mapInfo.width + mapInfo.widthType,
+							'height': mapInfo.height + mapInfo.heightType
 							};
 				var newFakeImage = editor.createFakeElement(newMapElement, 'cke_googlemaps' + mapInfo.number, 'div', false);
 				newFakeImage.setStyles( extraStyles );
@@ -406,7 +520,7 @@
 				{
 					// 項目を横に配置
 					type: 'hbox',
-					widths: [ '10%', '20%' ],		// 項目間幅を調整
+					widths: [ '10%', '10%', '10%', '20%' ],		// 項目間幅を調整
 	/*				padding: '5px',*/
 					children: [
 					{
@@ -429,6 +543,17 @@
 							resizeMap();
 						},
 						commit: commitValue
+					}, {
+						type: 'select',
+						id: 'cmbWidthType',
+						label: editor.lang.googlemaps.widthType,
+						style: 'width:50px',
+						'default': 'px',
+						items: [
+							[ 'px', 'px' ],
+							[ '%', '%' ]
+						],
+						commit: commitValue
 					}, {
 						type : 'text',
 						id : 'txtHeight',
@@ -449,6 +574,55 @@
 							resizeMap();
 						},
 						commit: commitValue
+					}, {
+						type: 'select',
+						id: 'cmbHeightType',
+						label: editor.lang.googlemaps.heightType,
+						style: 'width:50px',
+						'default': 'px',
+						items: [
+							[ 'px', 'px' ],
+							[ '%', '%' ]
+						],
+						commit: commitValue
+					}, {
+						type: 'checkbox',
+						id: 'chkAlignCenter',
+						label: editor.lang.googlemaps.alignCenter,
+						style: 'margin-top:20px;',
+						'default': false,
+						commit: commitValue
+					} ]
+				}, {
+					type: 'hbox',
+					widths: [ '10%', '10%', '10%' ],
+					children: [
+					{
+						type: 'text',
+						id: 'txtCenterLat',
+					//	requiredContent: 'img(cke-xyz)', // Random text like 'xyz' will check if all are allowed.
+						label: editor.lang.googlemaps.latitude,
+						'default': '',
+						onLoad: function(){
+							fieldCenterLatitude = document.getElementById(this.getInputElement().$.id);			// 参照を取得
+						},
+						onChange: function() {
+							if (mapObj) mapObj.setCenter(new google.maps.LatLng(this.getValue(), fieldCenterLongitude.value));
+						},
+						commit: commitValue
+					}, {
+						type: 'text',
+						id: 'txtCenterLon',
+						//requiredContent: 'img[title]',
+						label: editor.lang.googlemaps.longitude,
+						'default': '',
+						onLoad: function(){
+							fieldCenterLongitude = document.getElementById(this.getInputElement().$.id);		// 参照を取得
+						},
+						onChange: function() {
+							if (mapObj) mapObj.setCenter(new google.maps.LatLng(fieldCenterLatitude.value, this.getValue()));
+						},
+						commit: commitValue
 					}, {
 						type: 'select',
 						id: 'cmbZoom',
@@ -483,41 +657,130 @@
 						},
 						commit: commitValue
 					} ]
+				}, {
+					type: 'html',
+					html: '<div id="placeholder_map' + editor.id + '"><div id="gmapPreview' + editor.id + '" style="outline:0;" tabIndex="-1"></div></div>'
+				} ]		// elements
+			}, {
+				id: 'tab_option',
+				label: editor.lang.googlemaps.optionTitle,
+				elements: [
+				{
+					type: 'html',
+					html: editor.lang.googlemaps.control
 				}, {
 					type: 'hbox',
-					widths: [ '50%', '50%' ],
+					widths: [ '25%', '25%', '25%', '25%' ],
 					children: [
 					{
-						type: 'text',
-						id: 'txtCenterLat',
-					//	requiredContent: 'img(cke-xyz)', // Random text like 'xyz' will check if all are allowed.
-						label: editor.lang.googlemaps.latitude,
-						'default': '',
-						onLoad: function(){
-							fieldCenterLatitude = document.getElementById(this.getInputElement().$.id);			// 参照を取得
-						},
-						onChange: function() {
-							if (mapObj) mapObj.setCenter(new google.maps.LatLng(this.getValue(), fieldCenterLongitude.value));
+						type: 'checkbox',
+						id: 'chkZoomControl',
+						label: editor.lang.googlemaps.zoomControl,
+						'default': false,
+						onChange: function(){
+							changeMap(this.id);
 						},
 						commit: commitValue
 					}, {
-						type: 'text',
-						id: 'txtCenterLon',
-						//requiredContent: 'img[title]',
-						label: editor.lang.googlemaps.longitude,
-						'default': '',
-						onLoad: function(){
-							fieldCenterLongitude = document.getElementById(this.getInputElement().$.id);		// 参照を取得
+						type: 'checkbox',
+						id: 'chkPanControl',
+						label: editor.lang.googlemaps.panControl,
+						'default': false,
+						onChange: function(){
+							changeMap(this.id);
 						},
-						onChange: function() {
-							if (mapObj) mapObj.setCenter(new google.maps.LatLng(fieldCenterLatitude.value, this.getValue()));
+						commit: commitValue
+					}, {
+						type: 'checkbox',
+						id: 'chkMapTypeControl',
+						label: editor.lang.googlemaps.mapTypeControl,
+						'default': false,
+						onChange: function(){
+							changeMap(this.id);
+						},
+						commit: commitValue
+					}, {
+						type: 'checkbox',
+						id: 'chkScaleControl',
+						label: editor.lang.googlemaps.scaleControl,
+						'default': false,
+						onChange: function(){
+							changeMap(this.id);
+						},
+						commit: commitValue
+					} ]
+				}, {
+					type: 'hbox',
+					widths: [ '25%', '25%', '50%' ],
+					children: [
+					{
+						type: 'checkbox',
+						id: 'chkStreetViewControl',
+						label: editor.lang.googlemaps.streetViewControl,
+						'default': false,
+						onChange: function(){
+							changeMap(this.id);
+						},
+						commit: commitValue
+					}, {
+						type: 'checkbox',
+						id: 'chkRotateControl',
+						label: editor.lang.googlemaps.rotateControl,
+						'default': false,
+						onChange: function(){
+							changeMap(this.id);
+						},
+						commit: commitValue
+					}, {
+						type: 'checkbox',
+						id: 'chkOverviewMapControl',
+						label: editor.lang.googlemaps.overviewMapControl,
+						'default': false,
+						onChange: function(){
+							changeMap(this.id);
 						},
 						commit: commitValue
 					} ]
 				}, {
 					type: 'html',
-					html: '<div id="placeholder_map' + editor.id + '"><div id="gmapPreview' + editor.id + '" style="outline:0;" tabIndex="-1"></div></div>'
-				} ]		// elements
+					html: editor.lang.googlemaps.mapType
+				}, {
+					type: 'hbox',
+					widths: [ '25%', '25%', '25%', '25%' ],
+					children: [
+					{
+						type: 'checkbox',
+						id: 'chkRoadmapMapType',
+						label: editor.lang.googlemaps.roadmapMapType,
+						'default': false,
+						onChange: selectMap,
+						commit: commitValue
+					}, {
+						type: 'checkbox',
+						id: 'chkSatelliteMapType',
+						label: editor.lang.googlemaps.satelliteMapType,
+						'default': false,
+						onChange: selectMap,
+						commit: commitValue
+					}, {
+						type: 'checkbox',
+						id: 'chkHybridMapType',
+						label: editor.lang.googlemaps.hybridMapType,
+						'default': false,
+						onChange: selectMap,
+						commit: commitValue
+					}, {
+						type: 'checkbox',
+						id: 'chkTerrainMapType',
+						label: editor.lang.googlemaps.terrainMapType,
+						'default': false,
+						onChange: selectMap,
+						commit: commitValue
+					} ]
+				}, {
+					type: 'html',
+					html: '<div id="placeholder_option' + editor.id + '"></div>'
+				} ]
 			}, {
 				id: 'tab_search',
 				label: editor.lang.googlemaps.searchTitle,
@@ -579,6 +842,35 @@ html: '<img id="btnAddNewMarker' + editor.id + '" src="' + pluginUrl + 'images/A
 					hidden : true,
 					label: 'dummy item for the bug that the tab is auto disabled when all items are html type.'
 				} ]
+			}, {
+				id: 'tab_style',
+				label: editor.lang.googlemaps.styleTitle,
+				elements: [
+				{
+					type: 'html',
+					html: '<p>' + editor.lang.googlemaps.msgInputStyleJsonData + '</p>'
+				}, {
+					type: 'textarea',
+					id: 'txtStyle',
+					label: '',
+					'default': '',
+					inputStyle: 'cursor:auto;' +
+						'width:' + CKEDITOR.config.googlemaps_width + 'px;' +
+						'height:' + CKEDITOR.config.googlemaps_height + 'px;' +
+						'tab-size:4;' +
+						'text-align:left;',
+					validate : function() {
+						var pass = true,
+						value = this.getValue().trim();
+						pass = pass && (value == '' || isJson(value));
+						if ( !pass ){
+							alert( editor.lang.googlemaps.msgInvalidStyle );
+							this.select();
+						}
+						return pass;
+					},
+					commit: commitValue
+				} ]
 			} ]
 		};
 	});
