@@ -18,9 +18,12 @@ require_once($gEnvManager->getCommonPath() .	'/gitRepo.php');
 
 class admin_mainServerinfoWidgetContainer extends admin_mainBaseWidgetContainer
 {
+	private $cmdPath;		// ジョブ格納ディレクトリ
 	const MAGIC3_SRC_VER_FILE = '/var/magic3/src_version';
-	const CMD_FILENAME_UPDATE_INSTALL_PACKAGE = 'CMD_00_UPDATEINSTALLPACKAGE';			// インストールパッケージ取得ジョブファイル名
 	const WATCH_JOB_STATUS_FILE = 'STATUS';		// ジョブ状態確認用ファイル
+	const CMD_FILENAME_CREATE_SITE = 'CMD_00_CREATESITE';			// サイト作成ジョブファイル名
+	const CMD_FILENAME_REMOVE_SITE = 'CMD_00_REMOVESITE';			// サイト削除ジョブファイル名
+	const CMD_FILENAME_UPDATE_INSTALL_PACKAGE = 'CMD_00_UPDATEINSTALLPACKAGE';			// インストールパッケージ取得ジョブファイル名
 	
 	/**
 	 * コンストラクタ
@@ -29,6 +32,10 @@ class admin_mainServerinfoWidgetContainer extends admin_mainBaseWidgetContainer
 	{
 		// 親クラスを呼び出す
 		parent::__construct();
+		
+		// ジョブ格納ディレクトリ
+		$this->cmdPath = $this->gEnv->getCronjobsPath();
+		if (!file_exists($this->cmdPath)) mkdir($this->cmdPath, M3_SYSTEM_DIR_PERMISSION, true/*再帰的*/);
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -58,24 +65,31 @@ class admin_mainServerinfoWidgetContainer extends admin_mainBaseWidgetContainer
 		$units = array( 'B', 'KB', 'MB', 'GB', 'TB', 'EB', 'ZB', 'YB' );
 		$base = 1024;
 		$path = '/';
-		$cmdPath = $this->gEnv->getCronjobsPath();
-		$cmdFile_update_install_package = $cmdPath . DIRECTORY_SEPARATOR . self::CMD_FILENAME_UPDATE_INSTALL_PACKAGE;		// インストールパッケージの更新、コマンド実行ファイル
+		$cmdFile_update_install_package = $this->cmdPath . DIRECTORY_SEPARATOR . self::CMD_FILENAME_UPDATE_INSTALL_PACKAGE;		// インストールパッケージの更新、コマンド実行ファイル
 		
 		// ジョブの実行状況を表示
-		if (file_exists($cmdFile_update_install_package)) $this->setUserErrorMsg('インストーラの更新中です');
+		$isShownJobStatus = $this->_showJobStatus();
 
+		// マスターホストのディレクトリ名
+		$masterHostId = basename(dirname($this->gEnv->getSystemRootPath()));
+		
 		$act = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_ACT);
 		if ($act == 'getnewsrc'){		// 最新インストールパッケージ取得のとき
-			if (!file_exists($cmdPath)) mkdir($cmdPath, M3_SYSTEM_DIR_PERMISSION, true/*再帰的*/);
-			
 			// コマンドファイルにパラメータを書き込む
 			$cmdContent = '';
 			$email = $this->gEnv->getSiteEmail();
 			if (!empty($email)) $cmdContent .= 'mailto=' . $email . "\n";
 			$ret = file_put_contents($cmdFile_update_install_package, $cmdContent, LOCK_EX/*排他的アクセス*/);
 			if ($ret !== false){
-//echo '成功';
+				$this->tmpl->setAttribute('show_process_dialog', 'visibility', 'visible');		// 処理結果監視
 			}
+		} else if ($act == 'getinfo'){		// 最新情報取得
+			if (file_exists($cmdFile_update_install_package)){
+				$this->gInstance->getAjaxManager()->addData('code', '0');
+			} else {			// インストールパッケージ更新完了のとき
+				$this->gInstance->getAjaxManager()->addData('code', '1');
+			}
+			return;
 		}
 
 		//全体サイズ
@@ -108,9 +122,7 @@ class admin_mainServerinfoWidgetContainer extends admin_mainBaseWidgetContainer
 			$srcVer = trim($srcVer);
 			
 			// 最新バージョンの場合はインストール不可
-//			$disabled = '';
-//			if (!empty($srcVer) && version_compare($srcVer, $latestVersion) == 0) $disabled = 'disabled';
-			$this->tmpl->addVar("_widget", "update_src_button_disabled", $disabled);
+			$this->tmpl->addVar("_widget", "update_src_button_disabled", $this->convertToDisabledString((!empty($srcVer) && version_compare($srcVer, $latestVersion) == 0) || $isShownJobStatus));
 			
 			// 最新バージョン表示用
 			$versionInfoStr = '<span class="available">(最新版 ' . $latestVersion . ')</span>';
@@ -120,13 +132,14 @@ class admin_mainServerinfoWidgetContainer extends admin_mainBaseWidgetContainer
 		
 		// ジョブ監視状況
 		$watchJobStatus = '<span class="stopped">停止</span>';
-		if (file_exists($cmdPath . DIRECTORY_SEPARATOR . self::WATCH_JOB_STATUS_FILE)){
+		if (file_exists($this->cmdPath . DIRECTORY_SEPARATOR . self::WATCH_JOB_STATUS_FILE)){
 			// 10分以内にジョブが実行されている場合は稼動にする
-			$time = filemtime($cmdPath . DIRECTORY_SEPARATOR . self::WATCH_JOB_STATUS_FILE);
+			$time = filemtime($this->cmdPath . DIRECTORY_SEPARATOR . self::WATCH_JOB_STATUS_FILE);
 			if (time() - $time < 60 * 10) $watchJobStatus = '<span class="running">稼動中</span>';
 		}
 		
 		// 値を埋め込む
+		$this->tmpl->addVar('_widget', 'host_id',	$this->convertToDispString($masterHostId));			// ホストID
 		$this->tmpl->addVar('_widget', 'total_size',	$this->convertToDispString($totalStr));
 		$this->tmpl->addVar('_widget', 'free_size',		$this->convertToDispString($freeStr));
 		$this->tmpl->addVar('_widget', 'used_size',		$this->convertToDispString($usedStr));
@@ -134,5 +147,32 @@ class admin_mainServerinfoWidgetContainer extends admin_mainBaseWidgetContainer
 		$this->tmpl->addVar('_widget', 'watch_job_status',		$watchJobStatus);
 		$this->tmpl->addVar('_widget', 'src_version',	$this->convertToDispString($srcVer) . $versionInfoStr);
 	}
+	/**
+	 * ジョブの実行状況を表示
+	 *
+	 * @return bool			メッセージ表示ありかどうか
+	 */
+	function _showJobStatus()
+	{
+		$isShown = false;
+		
+		// ジョブの実行状況を表示
+		$cmdFile_create_site = $this->cmdPath . DIRECTORY_SEPARATOR . self::CMD_FILENAME_CREATE_SITE;		// サイト作成、コマンド実行ファイル
+		$cmdFile_remove_site = $this->cmdPath . DIRECTORY_SEPARATOR . self::CMD_FILENAME_REMOVE_SITE;		// サイト削除、コマンド実行ファイル
+		$cmdFile_update_insatll_package = $this->cmdPath . DIRECTORY_SEPARATOR . self::CMD_FILENAME_UPDATE_INSTALL_PACKAGE;			// インストールパッケージ取得ジョブファイル名
+		if (file_exists($cmdFile_create_site)){
+			$this->setUserErrorMsg('サイトの作成中です');
+			$isShown = true;			// メッセージ表示あり
+		}
+		if (file_exists($cmdFile_remove_site)){
+			$this->setUserErrorMsg('サイトの削除中です');
+			$isShown = true;			// メッセージ表示あり
+		}
+		if (file_exists($cmdFile_update_insatll_package)){
+			$this->setUserErrorMsg('インストーラの更新中です');
+			$isShown = true;			// メッセージ表示あり
+		}
+		return $isShown;
+	}
 }
 ?>
