@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2010 Magic3 Project.
+ * @copyright  Copyright 2006-2015 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_blog_update_boxWidgetContainer.php 3918 2011-01-01 03:20:22Z fishbone $
+ * @version    SVN: $Id$
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
@@ -60,6 +60,7 @@ class admin_blog_update_boxWidgetContainer extends BaseAdminWidgetContainer
 			$optionPassage = ($request->trimValueOf('item_option_passage') == 'on') ? 1 : 0;		// 表示オプション(経過日時)
 			
 			if ($this->getMsgCount() == 0){			// エラーのないとき
+				$paramObj = new stdClass;
 				$paramObj->itemCount	= $itemCount;
 				$paramObj->useRss	= $useRss;
 				$paramObj->optionPassage	= $optionPassage;		// 表示オプション(経過日時)
@@ -95,5 +96,19 @@ class admin_blog_update_boxWidgetContainer extends BaseAdminWidgetContainer
 		if ($optionPassage) $checked = 'checked';
 		$this->tmpl->addVar("_widget", "option_passage",	$checked);// 表示オプション(経過日時)
 	}
+	/**
+	 * テンプレートにデータ埋め込む
+	 *
+	 * _setTemplate()で指定したテンプレートファイルにデータを埋め込む。
+	 *
+	 * @param RequestManager $request		HTTPリクエスト処理クラス
+	 * @param object         $param			任意使用パラメータ。_setTemplate()と共有。
+	 * @return								なし
+	 */
+	function _postAssign($request, &$param)
+	{
+		// メニューバー、パンくずリスト作成(簡易版)
+		$this->createBasicConfigMenubar($request);
+	}
 }
 ?>
