@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2009 Magic3 Project.
+ * @copyright  Copyright 2006-2014 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: tracker.inc.php 1601 2009-03-21 05:51:06Z fishbone $
+ * @version    SVN: $Id: tracker.inc.php 3474 2010-08-13 10:36:48Z fishbone $
  * @link       http://www.magic3.org
  */
 // tracker_listで表示しないページ名(正規表現で)
@@ -22,14 +22,17 @@ define('TRACKER_LIST_EXCLUDE_PATTERN','#^SubMenu$|/#');
 // 項目の取り出しに失敗したページを一覧に表示する
 define('TRACKER_LIST_SHOW_ERROR_PAGE',TRUE);
 
+// Bootstrap用
+define('MAX_INPUT_TEXT_WIDTH_BOOTSTRAP', 40);
+define('MAX_TEXTAREA_WIDTH_BOOTSTRAP', 40);
+
 function plugin_tracker_convert()
 {
-	//global $script,$vars;
 	global $script;
+	global $gEnvManager;
 
 	if (PKWK_READONLY) return ''; // Show nothing
 
-	//$base = $refer = $vars['page'];
 	$base = $refer = WikiParam::getPage();
 
 	$config_name = 'default';
@@ -80,7 +83,17 @@ function plugin_tracker_convert()
 		}
 		$retval = str_replace("[$name]",$replace,$retval);
 	}
-	return <<<EOD
+	// テンプレートタイプに合わせて出力を変更
+	$templateType = $gEnvManager->getCurrentTemplateType();
+	if ($templateType == M3_TEMPLATE_BOOTSTRAP_30){		// Bootstrap型テンプレートの場合
+		return <<<EOD
+<form enctype="multipart/form-data" action="$script" method="post" class="form form-inline" role="form">
+$retval
+$hiddens
+</form>
+EOD;
+	} else {
+		return <<<EOD
 <form enctype="multipart/form-data" action="$script" method="post" class="form">
 <div>
 $retval
@@ -88,15 +101,14 @@ $hiddens
 </div>
 </form>
 EOD;
+	}
 }
 function plugin_tracker_action()
 {
-	//global $post, $vars, $now;
 	global $now;
 
 	if (PKWK_READONLY) die_message('PKWK_READONLY prohibits editing');
 
-	//$config_name = array_key_exists('_config',$post) ? $post['_config'] : '';
 	$config_name = WikiParam::getPostVar('_config');
 
 	$config = new Config('plugin/tracker/'.$config_name);
@@ -245,7 +257,7 @@ function plugin_tracker_get_fields($base,$refer,&$config)
 		) as $field=>$class)
 	{
 		$class = 'Tracker_field_'.$class;
-		$fields[$field] = &new $class(array($field,$_tracker_messages["btn$field"],'','20',''),$base,$refer,$config);
+		$fields[$field] = new $class(array($field,$_tracker_messages["btn$field"],'','20',''),$base,$refer,$config);
 	}
 
 	foreach ($config->get('fields') as $field)
@@ -258,7 +270,7 @@ function plugin_tracker_get_fields($base,$refer,&$config)
 			$field[2] = 'text';
 			$field[3] = '20';
 		}
-		$fields[$field[0]] = &new $class($field,$base,$refer,$config);
+		$fields[$field[0]] = new $class($field,$base,$refer,$config);
 	}
 	return $fields;
 }
@@ -288,7 +300,7 @@ class Tracker_field
 		$this->default_value = $field[4];
 		$this->page = $page;
 		$this->refer = $refer;
-		$this->config = &$config;
+		$this->config = $config;
 		//$this->data = array_key_exists($this->name,$post) ? $post[$this->name] : '';
 		$this->data = WikiParam::getPostVar($this->name);
 	}
@@ -318,10 +330,20 @@ class Tracker_field_text extends Tracker_field
 
 	function get_tag()
 	{
+		global $gEnvManager;
+			
 		$s_name = htmlspecialchars($this->name);
 		$s_size = htmlspecialchars($this->values[0]);
 		$s_value = htmlspecialchars($this->default_value);
-		return "<input type=\"text\" name=\"$s_name\" size=\"$s_size\" value=\"$s_value\" />";
+		
+		// テンプレートタイプに合わせて出力を変更
+		$templateType = $gEnvManager->getCurrentTemplateType();
+		if ($templateType == M3_TEMPLATE_BOOTSTRAP_30){		// Bootstrap型テンプレートの場合
+			if ($s_size > MAX_INPUT_TEXT_WIDTH_BOOTSTRAP) $s_size = MAX_INPUT_TEXT_WIDTH_BOOTSTRAP;
+			return "<input type=\"text\" class=\"form-control\" name=\"$s_name\" size=\"$s_size\" value=\"$s_value\" />";
+		} else {
+			return "<input type=\"text\" name=\"$s_name\" size=\"$s_size\" value=\"$s_value\" />";
+		}
 	}
 }
 class Tracker_field_page extends Tracker_field_text
@@ -360,11 +382,21 @@ class Tracker_field_textarea extends Tracker_field
 
 	function get_tag()
 	{
+		global $gEnvManager;
+		
 		$s_name = htmlspecialchars($this->name);
 		$s_cols = htmlspecialchars($this->values[0]);
 		$s_rows = htmlspecialchars($this->values[1]);
 		$s_value = htmlspecialchars($this->default_value);
-		return "<textarea name=\"$s_name\" cols=\"$s_cols\" rows=\"$s_rows\">$s_value</textarea>";
+		
+		// テンプレートタイプに合わせて出力を変更
+		$templateType = $gEnvManager->getCurrentTemplateType();
+		if ($templateType == M3_TEMPLATE_BOOTSTRAP_30){		// Bootstrap型テンプレートの場合
+			$s_cols = MAX_TEXTAREA_WIDTH_BOOTSTRAP;
+			return "<textarea class=\"form-control\" name=\"$s_name\" cols=\"$s_cols\" rows=\"$s_rows\">$s_value</textarea>";
+		} else {
+			return "<textarea name=\"$s_name\" cols=\"$s_cols\" rows=\"$s_rows\">$s_value</textarea>";
+		}
 	}
 	function format_cell($str)
 	{
@@ -456,18 +488,31 @@ class Tracker_field_radio extends Tracker_field_format
 
 	function get_tag()
 	{
+		global $gEnvManager;
+		
 		$s_name = htmlspecialchars($this->name);
 		$retval = '';
 		$id = 0;
+		
+		// テンプレートタイプに合わせて出力を変更
+		$templateType = $gEnvManager->getCurrentTemplateType();
+		
 		foreach ($this->config->get($this->name) as $option)
 		{
 			$s_option = htmlspecialchars($option[0]);
 			$checked = trim($option[0]) == trim($this->default_value) ? ' checked="checked"' : '';
 			++$id;
 			$s_id = '_p_tracker_' . $s_name . '_' . $this->id . '_' . $id;
-			$retval .= '<input type="radio" name="' .  $s_name . '" id="' . $s_id .
-				'" value="' . $s_option . '"' . $checked . ' />' .
-				'<label for="' . $s_id . '">' . $s_option . '</label>' . "\n";
+			
+			if ($templateType == M3_TEMPLATE_BOOTSTRAP_30){		// Bootstrap型テンプレートの場合
+				$retval .= '<div class="radio-inline"><input type="radio" name="' .  $s_name . '" id="' . $s_id .
+					'" value="' . $s_option . '"' . $checked . ' />' .
+					'<label for="' . $s_id . '">' . $s_option . '</label></div>' . "\n";
+			} else {
+				$retval .= '<input type="radio" name="' .  $s_name . '" id="' . $s_id .
+					'" value="' . $s_option . '"' . $checked . ' />' .
+					'<label for="' . $s_id . '">' . $s_option . '</label>' . "\n";
+			}
 		}
 
 		return $retval;
@@ -492,12 +537,21 @@ class Tracker_field_select extends Tracker_field_radio
 
 	function get_tag($empty=FALSE)
 	{
+		global $gEnvManager;
+		
 		$s_name = htmlspecialchars($this->name);
 		$s_size = (array_key_exists(0,$this->values) and is_numeric($this->values[0])) ?
 			' size="'.htmlspecialchars($this->values[0]).'"' : '';
 		$s_multiple = (array_key_exists(1,$this->values) and strtolower($this->values[1]) == 'multiple') ?
 			' multiple="multiple"' : '';
-		$retval = "<select name=\"{$s_name}[]\"$s_size$s_multiple>\n";
+			
+		// テンプレートタイプに合わせて出力を変更
+		$templateType = $gEnvManager->getCurrentTemplateType();
+		if ($templateType == M3_TEMPLATE_BOOTSTRAP_30){		// Bootstrap型テンプレートの場合
+			$retval = "<select class=\"form-control\" name=\"{$s_name}[]\"$s_size$s_multiple>\n";
+		} else {
+			$retval = "<select name=\"{$s_name}[]\"$s_size$s_multiple>\n";
+		}
 		if ($empty)
 		{
 			$retval .= " <option value=\"\"></option>\n";
@@ -520,10 +574,16 @@ class Tracker_field_checkbox extends Tracker_field_radio
 
 	function get_tag($empty=FALSE)
 	{
+		global $gEnvManager;
+		
 		$s_name = htmlspecialchars($this->name);
 		$defaults = array_flip(preg_split('/\s*,\s*/',$this->default_value,-1,PREG_SPLIT_NO_EMPTY));
 		$retval = '';
 		$id = 0;
+		
+		// テンプレートタイプに合わせて出力を変更
+		$templateType = $gEnvManager->getCurrentTemplateType();
+		
 		foreach ($this->config->get($this->name) as $option)
 		{
 			$s_option = htmlspecialchars($option[0]);
@@ -531,9 +591,16 @@ class Tracker_field_checkbox extends Tracker_field_radio
 				' checked="checked"' : '';
 			++$id;
 			$s_id = '_p_tracker_' . $s_name . '_' . $this->id . '_' . $id;
-			$retval .= '<input type="checkbox" name="' . $s_name .
-				'[]" id="' . $s_id . '" value="' . $s_option . '"' . $checked . ' />' .
-				'<label for="' . $s_id . '">' . $s_option . '</label>' . "\n";
+			
+			if ($templateType == M3_TEMPLATE_BOOTSTRAP_30){		// Bootstrap型テンプレートの場合
+				$retval .= '<div class="checkbox-inline"><input type="checkbox" name="' . $s_name .
+					'[]" id="' . $s_id . '" value="' . $s_option . '"' . $checked . ' />' .
+					'<label for="' . $s_id . '">' . $s_option . '</label></div>' . "\n";
+			} else {
+				$retval .= '<input type="checkbox" name="' . $s_name .
+					'[]" id="' . $s_id . '" value="' . $s_option . '"' . $checked . ' />' .
+					'<label for="' . $s_id . '">' . $s_option . '</label>' . "\n";
+			}
 		}
 
 		return $retval;
@@ -596,10 +663,7 @@ class Tracker_field_past extends Tracker_field
 // 一覧表示
 function plugin_tracker_list_convert()
 {
-	//global $vars;
-
 	$config = 'default';
-	//$page = $refer = $vars['page'];
 	$page = $refer = WikiParam::getPage();
 	$field = '_page';
 	$order = '';
@@ -626,18 +690,13 @@ function plugin_tracker_list_convert()
 }
 function plugin_tracker_list_action()
 {
-	//global $script,$vars,$_tracker_messages;
 	global $script,$_tracker_messages;
 
-	//$page = $refer = $vars['refer'];
 	$page = $refer = WikiParam::getRefer();
 	$s_page = make_pagelink($page);
-	//$config = $vars['config'];
 	$config = WikiParam::getVar('config');
-	//$list = array_key_exists('list',$vars) ? $vars['list'] : 'list';
 	$list = WikiParam::getVar('list');
 	if ($list == '') $list = 'list';
-	//$order = array_key_exists('order',$vars) ? $vars['order'] : '_real:SORT_DESC';
 	$order = WikiParam::getVar('order');
 	if ($order == '') $order = '_real:SORT_DESC';
 
@@ -663,7 +722,7 @@ function plugin_tracker_getlist($page,$refer,$config_name,$list,$order='',$limit
 		return "<p>config file '".make_pagelink($config->page.'/'.$list)."' not found.</p>";
 	}
 
-	$list = &new Tracker_list($page,$refer,$config,$list);
+	$list = new Tracker_list($page,$refer,$config,$list);
 	$list->sort($order);
 	return $list->toString($limit);
 }
@@ -683,7 +742,7 @@ class Tracker_list
 	function Tracker_list($page,$refer,&$config,$list)
 	{
 		$this->page = $page;
-		$this->config = &$config;
+		$this->config = $config;
 		$this->list = $list;
 		$this->fields = plugin_tracker_get_fields($page,$refer,$config);
 
@@ -812,7 +871,7 @@ class Tracker_list
 			$params[] = $order;
 
 		}
-		$params[] = &$this->rows;
+		$params[] = $this->rows;
 
 		call_user_func_array('array_multisort',$params);
 	}
@@ -910,7 +969,7 @@ class Tracker_list
 		{
 			if (preg_match('/^\|(.+)\|[hHfFcC]$/',$line))
 			{
-				$source .= preg_replace_callback('/\[([^\[\]]+)\]/',array(&$this,'replace_title'),$line);
+				$source .= preg_replace_callback('/\[([^\[\]]+)\]/',array($this,'replace_title'),$line);
 			}
 			else
 			{
@@ -932,7 +991,7 @@ class Tracker_list
 					continue;
 				}
 				$this->pipe = ($line{0} == '|' or $line{0} == ':');
-				$source .= preg_replace_callback('/\[([^\[\]]+)\]/',array(&$this,'replace_item'),$line);
+				$source .= preg_replace_callback('/\[([^\[\]]+)\]/',array($this,'replace_item'),$line);
 			}
 		}
 		return convert_html($source);
